#
# spec file for package python-pycrypto
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-pycrypto
Version:        2.6.1
Release:        2.1
Url:            http://www.pycrypto.org/
Summary:        Cryptographic modules for Python
License:        Python-2.0
Group:          Development/Languages/Python
Source:         https://ftp.dlitz.net/pub/dlitz/crypto/pycrypto/pycrypto-%{version}.tar.gz
# PATCH-FIX-SUSE: We don't have libgmp5 on SLE11
Patch0:         ignore-fastmath-warning.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gmp-devel
BuildRequires:  python-devel
%if 0%{?rhel}
Provides:       python2-crypto = %{version}
Obsoletes:      python2-crypto < %{version}
%else
Provides:       python-crypto = %{version}
Obsoletes:      python-crypto < %{version}
%endif
%if 0%{?suse_version} && 0%{?suse_version} <= 1110 || 0%{?rhel} == 5
%{!?python_sitearch: %global python_sitearch %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
%endif

%description
The package contains:

  * Hash functions: MD2, MD4, RIPEMD, SHA256.
  * Block encryption algorithms: AES, ARC2, Blowfish, CAST, DES,
    Triple-DES, IDEA, RC5.
  * Stream encryption algorithms: ARC4, simple XOR.
  * Public-key algorithms: RSA, DSA, ElGamal, qNEW.
  * Protocols: All-or-nothing transforms, chaffing/winnowing.
  * Miscellaneous: RFC1751 module for converting 128-key keys into a
    set of English words, primality testing.
  * Some demo programs (currently all quite old and outdated).

%prep
%setup -q -n pycrypto-%{version}
%if 0%{?suse_version} < 1120
%patch0
%endif

%build
CFLAGS="%{optflags} -fno-strict-aliasing" python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
python setup.py test

%files
%defattr(-,root,root)
%doc ACKS ChangeLog COPYRIGHT README
%{python_sitearch}/Crypto/
%{python_sitearch}/pycrypto-%{version}-py*.egg-info

%changelog
* Tue Oct  1 2019 jbreuer@suse.de
- Adding "Provides" and "Obsoletes" for Centos/Rhel (bsc#1146383)
* Wed Apr 23 2014 rschweikert@suse.com
- Include in SLE 12 (FATE #315990)
* Wed Nov 27 2013 p.drouand@gmail.com
- Update to version 2.6.1
  * [CVE-2013-1445] Fix PRNG not correctly reseeded in some situations.
  In previous versions of PyCrypto, the Crypto.Random PRNG exhibits a
  race condition that may cause forked processes to generate identical
  sequences of 'random' numbers.
  This is a fairly obscure bug that will (hopefully) not affect many
  applications, but the failure scenario is pretty bad.  Here is some
  sample code that illustrates the problem:
  from binascii import hexlify
  import multiprocessing, pprint, time
  import Crypto.Random
  def task_main(arg):
  a = Crypto.Random.get_random_bytes(8)
  time.sleep(0.1)
  b = Crypto.Random.get_random_bytes(8)
  rdy, ack = arg
  rdy.set()
  ack.wait()
  return "%%s,%%s" %% (hexlify(a).decode(),
  hexlify(b).decode())
  n_procs = 4
  manager = multiprocessing.Manager()
  rdys = [manager.Event() for i in range(n_procs)]
  acks = [manager.Event() for i in range(n_procs)]
  Crypto.Random.get_random_bytes(1)
  pool = multiprocessing.Pool(processes=n_procs,
  initializer=Crypto.Random.atfork)
  res_async = pool.map_async(task_main, zip(rdys, acks))
  pool.close()
  [rdy.wait() for rdy in rdys]
  [ack.set() for ack in acks]
  res = res_async.get()
  pprint.pprint(sorted(res))
  pool.join()
  The output should be random, but it looked like this:
  ['c607803ae01aa8c0,2e4de6457a304b34',
  'c607803ae01aa8c0,af80d08942b4c987',
  'c607803ae01aa8c0,b0e4c0853de927c4',
  'c607803ae01aa8c0,f0362585b3fceba4']
  This release fixes the problem by resetting the rate-limiter when
  Crypto.Random.atfork() is invoked.  It also adds some tests and a
  few related comments.
- Add "-fno-strict-aliasing" to CFLAGS
* Wed Jun 12 2013 dmueller@suse.com
- add ignore-fastmath-warning.diff for SLE11 and older
* Wed Apr 24 2013 highwaystar.ru@gmail.com
- update to 2.6
  * [CVE-2012-2417] Fix LP#985164: insecure ElGamal key generation.
    (thanks: Legrandin)
    In the ElGamal schemes (for both encryption and signatures), g is
    supposed to be the generator of the entire Z^*_p group.  However, in
    PyCrypto 2.5 and earlier, g is more simply the generator of a random
    sub-group of Z^*_p.
    The result is that the signature space (when the key is used for
    signing) or the public key space (when the key is used for encryption)
    may be greatly reduced from its expected size of log(p) bits, possibly
    down to 1 bit (the worst case if the order of g is 2).
    While it has not been confirmed, it has also been suggested that an
    attacker might be able to use this fact to determine the private key.
    Anyone using ElGamal keys should generate new keys as soon as practical.
    Any additional information about this bug will be tracked at
    https://bugs.launchpad.net/pycrypto/+bug/985164
  * Huge documentation cleanup (thanks: Legrandin).
  * Added more tests, including test vectors from NIST 800-38A
    (thanks: Legrandin)
  * Remove broken MODE_PGP, which never actually worked properly.
    A new mode, MODE_OPENPGP, has been added for people wishing to write
    OpenPGP implementations.  Note that this does not implement the full
    OpenPGP specification, only the "OpenPGP CFB mode" part of that
    specification.
    https://bugs.launchpad.net/pycrypto/+bug/996814
  * Fix: getPrime with invalid input causes Python to abort with fatal error
    https://bugs.launchpad.net/pycrypto/+bug/988431
  * Fix: Segfaults within error-handling paths
    (thanks: Paul Howarth & Dave Malcolm)
    https://bugs.launchpad.net/pycrypto/+bug/934294
  * Fix: Block ciphers allow empty string as IV
    https://bugs.launchpad.net/pycrypto/+bug/997464
  * Fix DevURandomRNG to work with Python3's new I/O stack.
    (thanks: Sebastian Ramacher)
  * Remove automagic dependencies on libgmp and libmpir, let the caller
    disable them using args.
  * Many other minor bug fixes and improvements (mostly thanks to Legrandin)
* Mon Sep  3 2012 jengelh@inai.de
- Make package build on RH6-like systems
* Thu May 24 2012 highwaystar.ru@gmail.com
- python3 package added
- minor spec improvement
* Mon Mar 12 2012 saschpe@gmx.de
- Update to version 2.5:
  * Added PKCS#1 encryption schemes (v1.5 and OAEP).  We now have
    a decent, easy-to-use non-textbook RSA implementation.  Yay!
  * Added PKCS#1 signature schemes (v1.5 and PSS). v1.5 required some
    extensive changes to Hash modules to contain the algorithm specific
    ASN.1 OID. To that end, we now always have a (thin) Python module to
    hide the one in pure C.
  * Added 2 standard Key Derivation Functions (PBKDF1 and PBKDF2).
  * Added export/import of RSA keys in OpenSSH and PKCS#8 formats.
  * Added password-protected export/import of RSA keys (one old method
    for PKCS#8 PEM only).
  * Added ability to generate RSA key pairs with configurable public
    exponent e.
  * Added ability to construct an RSA key pair even if only the private
    exponent d is known, and not p and q.
  * Added SHA-2 C source code (fully from Lorenz Quack).
  * Unit tests for all the above.
  * Updates to documentation (both inline and in Doc/pycrypt.rst)
  * All of the above changes were put together by Legrandin (Thanks!)
  * Minor bug fixes (setup.py and tests).
- Changes from version 2.4.1:
  * Fix "error: Setup script exited with error: src/config.h: No such file or
    directory" when installing via easy_install.  (Sebastian Ramacher)
- Changes from version 2.4:
  * Python 3 support!  (Thorsten E. Behrens, Anders Sundman)
    PyCrypto now supports every version of Python from 2.1 through 3.2.
  * Timing-attack countermeasures in _fastmath: When built against
    libgmp version 5 or later, we use mpz_powm_sec instead of mpz_powm.
    This should prevent the timing attack described by Geremy Condra at
    PyCon 2011:
    http://blip.tv/pycon-us-videos-2009-2010-2011/pycon-2011-through-the-side-channel-timing-and-implementation-attacks-in-python-4897955
  * New hash modules (for Python >= 2.5 only): SHA224, SHA384, and
    SHA512 (Frédéric Bertolus)
  * Configuration using GNU autoconf.  This should help fix a bunch of
    build issues.
  * Support using MPIR as an alternative to GMP.
  * Improve the test command in setup.py, by allowing tests to be
    performed on a single sub-package or module only. (Legrandin)
  * Fix double-decref of "counter" when Cipher object initialisation
    fails (Ryan Kelly)
  * Apply patches from Debian's python-crypto 2.3-3 package (Jan
    Dittberner, Sebastian Ramacher):
  - fix-RSA-generate-exception.patch
  - epydoc-exclude-introspect.patch
  - no-usr-local.patch
  * Fix launchpad bug #702835: "Import key code is not compatible with
    GMP library" (Legrandin)
  * More tests, better documentation, various bugfixes.
* Thu Sep  1 2011 saschpe@suse.de
- Set license to Python-2.0, fixes bnc#715456
* Wed Aug 31 2011 saschpe@gmx.de
- Drop pycrypto-2.1.0-ssize.patch to fix SLE build
* Wed Aug 31 2011 saschpe@gmx.de
- Initial version, replaces python-crypto
